@@ -1,19 +1,30 @@
 # Wishrc startup for ToolScript (xcircuit)
 #
-# load /usr/local/share/xcircuit-3.0/xcircuit.so
+# Loads the shared object (xcircuit.so) file into Tcl, runs the
+# wrapper script to generate the GUI, then runs the initialization
+# routine for the XCircuit package.
+
+global XCOps
 
 set envlibdir [array get env "XCIRCUIT_LIB_DIR"]
-if {$envlibdir != {}} {
-   set path [lindex $envlibdir 1]
-} else {
-   set path "/usr/local/lib/xcircuit-3.4"
-   set XCIRCUIT_LIB_DIR $path
+if {$envlibdir == {}} {
+   set XCIRCUIT_LIB_DIR /usr/local/lib/xcircuit-3.6
 }
 unset envlibdir
 
-set libext .so
+set envsrcdir [array get env "XCIRCUIT_SRC_DIR"]
+if {$envsrcdir != {}} {
+   set path [lindex $envsrcdir 1]
+} else {
+   set path /usr/local/lib/xcircuit-3.6
+   set XCIRCUIT_SRC_DIR $path
+}
+unset envsrcdir
+
 if {[string compare $tcl_platform(platform) "windows"] == 0} {
    set libext .dll
+} else {
+   set libext .so
 }
 
 set tcllibdir $path
@@ -197,7 +208,7 @@ unset envhomedir
 if {[string length $argv] == 0} {
    # Source the GUI-generating script
    source ${tcllibdir}/wrapper.tcl
-   xcircuit::start
+   xcircuit::start .xcircuit
 } else {
    set do_wrapper true
    set argafter {xcircuit::start}
@@ -207,6 +218,12 @@ if {[string length $argv] == 0} {
 	 ^-now {
 	   set do_wrapper false
 	 }
+	 ^-r {
+	   set XCOps(library) "all"
+	 }
+	 ^-noc {
+	   # this option already handled---absorb it and do nothing.
+	 }
 	 default {
 	   lappend argafter $x
 	 }
@@ -217,18 +234,22 @@ if {[string length $argv] == 0} {
    if {$do_wrapper} {
       # Source the GUI-generating script
       source ${tcllibdir}/wrapper.tcl
+      set argafter [linsert $argafter 1 .xcircuit]
    } else {
       simple .xcdummy -exitproc "quitnocheck"
       set XCOps(window) .xcdummy
    }
    unset x i do_wrapper
-   eval $argafter		;# xcircuit::start ${argv}
+   eval $argafter		;# xcircuit::start .xcircuit ${argv}
 }
 unset tcllibdir
 
 # The GUI wrapper iconfies the window while generating it
 catch {wm deiconify $XCOps(toplevel)}
 
+# Invoke the "wire" button by default
+catch {$XCOps(focus).mainframe.toolbar.bw invoke}
+
 # Xcircuit start function drops back to interpreter after initialization & setup
 
 if {[string range [wm title .] 0 3] == "wish"} {
